@@ -1,11 +1,11 @@
 from typing import List, Type, Optional
 from pydfs_lineup_optimizer.settings import BaseSettings, LineupPosition
-from pydfs_lineup_optimizer.constants import Sport, Site, PlayerRank
+from pydfs_lineup_optimizer.constants import Sport, Site
 from pydfs_lineup_optimizer.sites.sites_registry import SitesRegistry
 from pydfs_lineup_optimizer.lineup_printer import IndividualSportLineupPrinter
-from pydfs_lineup_optimizer.rules import OptimizerRule, FanduelBaseballRosterRule, FanduelSingleGameStarRule
-from pydfs_lineup_optimizer.sites.fanduel.classic.importer import FanDuelCSVImporter
-from pydfs_lineup_optimizer.sites.fanduel.single_game.importer import build_fanduel_single_game_importer
+from pydfs_lineup_optimizer.rules import OptimizerRule, FanduelBaseballRosterRule
+from pydfs_lineup_optimizer.sites.fanduel.classic.importer import FanDuelCSVImporter, FanDuelLOLCSVImporter, \
+    FanDuelMVPCSVImporter
 
 
 class FanDuelSettings(BaseSettings):
@@ -122,10 +122,9 @@ class FanDuelLOLSettings(FanDuelSettings):
     sport = Sport.LEAGUE_OF_LEGENDS
     max_from_one_team = 4
     min_teams = 3
-    csv_importer = build_fanduel_single_game_importer(mvp=False, star=True, pro=False)
-    extra_rules = [FanduelSingleGameStarRule]  # type: List[Type[OptimizerRule]]
+    csv_importer = FanDuelLOLCSVImporter
     positions = [
-        LineupPosition('STAR', ('TOP', 'MID', 'ADC', 'JNG', 'SUP'), for_rank=PlayerRank.STAR),
+        LineupPosition('STAR', ('STAR', )),
         LineupPosition('TOP', ('TOP',)),
         LineupPosition('JNG', ('JNG',)),
         LineupPosition('MID', ('MID',)),
@@ -133,3 +132,38 @@ class FanDuelLOLSettings(FanDuelSettings):
         LineupPosition('SUP', ('SUP',)),
         LineupPosition('TEAM', ('TEAM',)),
     ]
+    
+    
+@SitesRegistry.register_settings
+class FanDuelNascarSettings(FanDuelSettings):
+    sport = Sport.NASCAR
+    budget = 50000
+    max_from_one_team = None
+    min_teams = None
+    lineup_printer = IndividualSportLineupPrinter
+    positions = [
+        LineupPosition('D', ('D', )),
+        LineupPosition('D', ('D', )),
+        LineupPosition('D', ('D', )),
+        LineupPosition('D', ('D', )),
+        LineupPosition('D', ('D', )),
+    ]
+
+
+@SitesRegistry.register_settings
+class FanDuelMMASettings(FanDuelSettings):
+    sport = Sport.MMA
+    max_from_one_team = None
+    min_teams = None
+    budget = 100
+    csv_importer = FanDuelMVPCSVImporter
+    lineup_printer = IndividualSportLineupPrinter
+    positions = [
+        LineupPosition('MVP', ('MVP', )),
+        LineupPosition('F', ('F', )),
+        LineupPosition('F', ('F', )),
+        LineupPosition('F', ('F', )),
+        LineupPosition('F', ('F', )),
+        LineupPosition('F', ('F', )),
+    ]
+
